Learn R Programming

cubicBsplines (version 1.0.0)

Bsplines: Computation of a cubic B-spline basis associated to a given vector of knots

Description

Computation of a cubic B-spline basis associated to a given vector of knots

Usage

Bsplines(x, knots)

Arguments

x

vector of values where the B-spline basis must be evaluated.

knots

vector of knots spanning the desired B-spline basis.

Value

A matrix of dimension length(x) by (length(knots)+2).

Each column of the matrix corresponds to one cubic B-spline in the basis.

Examples

Run this code
# NOT RUN {
Bsplines(x=runif(20),knots=seq(0,1,length=11))
# }

Run the code above in your browser using DataLab