powered by
Computation of a cubic B-spline basis associated to a given vector of knots
Bsplines(x, knots)
vector of values where the B-spline basis must be evaluated.
vector of knots spanning the desired B-spline basis.
A matrix of dimension length(x) by (length(knots)+2).
length(x)
(length(knots)+2)
Each column of the matrix corresponds to one cubic B-spline in the basis.
# NOT RUN { Bsplines(x=runif(20),knots=seq(0,1,length=11)) # }
Run the code above in your browser using DataLab